/*
  HMat-OSS (HMatrix library, open source software)

  Copyright (C) 2014-2015 Airbus Group SAS

  This program is free software; you can redistribute it and/or
  modify it under the terms of the GNU General Public License
  as published by the Free Software Foundation; either version 2
  of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

  http://github.com/jeromerobert/hmat-oss
*/

/* Contient des definitions permettant d'acceder a certaines parties de LAPACK
   dans la MKL. */
#ifndef _LAPACK_OPERATIONS_HPP
#define _LAPACK_OPERATIONS_HPP
#include "data_types.hpp"
#include "full_matrix.hpp"

namespace hmat {

template <typename T>
int sddCall(char jobz, int m, int n, T *a, int lda,
            typename hmat::Types<T>::real *sigma, T *u, int ldu, T *vt,
            int ldvt);
template <typename T>
int svdCall(char jobu, char jobv, int m, int n, T *a, int lda,
            typename hmat::Types<T>::real *sigma, T *u, int ldu, T *vt,
            int ldvt);

}  // end namespace hmat

#endif
